@@ -1,25 +1,28 @@
-from asyncio import get_event_loop, start_server, StreamReader, StreamWriter
-from .config import cfg
-from .channel import channels, Channel
-from .util import add_task
+from asyncio import start_server, StreamReader, StreamWriter
 from traceback import format_exc
 
-__all__ = 'start_command_server',
+from .channel import channels, Channel
+from .config import cfg
+from .util import add_task, task_running, stop_task
+
+__all__ = 'start_command_server', 'stop_command_server'
 
 HOST = cfg.command_server_host
 PORT = cfg.command_server_port
 ENABLED = cfg.command_server_enabled
-COMMAND_TASK_ID = 'COMMAND_SERVER'
+COMMAND_SERVER_TASK_ID = 'COMMAND_SERVER'
 
 
 def start_command_server():
     if not ENABLED:
         return
 
-    print(f'starting command server on {HOST}:{PORT}')
+    stop_command_server()
+
+    print(f'starting command server (view host / port in config file)')
     try:
         # noinspection PyTypeChecker
-        add_task(COMMAND_TASK_ID, start_server(handle_client, HOST, PORT))
+        add_task(COMMAND_SERVER_TASK_ID, start_server(handle_client, HOST, PORT))
     except Exception as e:
         print(f"\n------COMMAND SERVER------\nfailed to bind/create command server\n"
               f"this does not affect the bot, but it does mean that the command console will not work/be usable\n"
@@ -29,6 +32,11 @@ def start_command_server():
               f'------COMMAND SERVER------\n')
 
 
+def stop_command_server():
+    if task_running(COMMAND_SERVER_TASK_ID):
+        stop_task(COMMAND_SERVER_TASK_ID)
+
+
 async def handle_client(reader: StreamReader, writer: StreamWriter):
     # helper function to read the next message from the client
     async def read():
