@@ -1,4 +1,4 @@
-from typing import List, Tuple, TYPE_CHECKING, Optional
+from typing import List, Tuple, TYPE_CHECKING, Optional, Callable, Awaitable
 
 from twitchbot import get_bot
 from .util import get_message_mentions
@@ -104,7 +104,7 @@ class Message:
             self.mentions = get_message_mentions(self)
 
             # checking if its a channel point redemption
-            self.reward = self.tags.all_tags.get('msg-id')
+            self.reward = self.tags.all_tags.get('msg-id') or self.tags.all_tags.get('custom-reward-id')
             if self.reward is not None:
                 self.type = MessageType.CHANNEL_POINTS_REDEMPTION
 
@@ -185,6 +185,27 @@ class Message:
         # else:
         #     raise ValueError(f'invalid message type to reply, expected PRIVMSG or WHISPER, current: {self.type}')
 
+    async def wait_for_reply(self, predicate: Callable[['Message'], Awaitable[bool]] = None, timeout=30, default=None,
+                             raise_on_timeout=False) -> 'Message':
+        """
+        waits for a message matching `predicate` to be received, when its received, it returns that message.
+
+        if no message matching `predicate` is received by the timeout, the default will be returned.
+
+        if raise_on_timeout is True and no matching message is received, this function will raise asyncio.TimeoutError
+
+        if raise_on_timeout is False and no matching message is received, default will be returned when it times-out
+
+        default is by default is None
+        raise_on_timeout by default is False
+        predicate defaults to `same_author_predicate`
+        """
+
+        from .replywaiter import wait_for_reply, same_author_predicate
+
+        return await wait_for_reply(predicate or same_author_predicate(self), timeout=timeout, default=default,
+                                    raise_on_timeout=raise_on_timeout)
+
     def __str__(self):
         if self.type is MessageType.PRIVMSG:
             return f'{self.author}({self.channel.name}): {self.content}'
@@ -211,10 +232,21 @@ class Message:
             return f'{self.author} left {self.channel_name}'
 
         elif self.type is MessageType.CHANNEL_POINTS_REDEMPTION:
-            return f'{self.author} redeemws reward {self.reward} in #{self.channel_name}'
+            return f'{self.author} redeemed reward {self.reward} in #{self.channel_name}'
 
         return self.raw_msg
 
+    def __getitem__(self, item):
+        """
+        if item is a slice, returns a space joined parts of that slice
+
+        if item in a int, returns a single part at that index
+        """
+        if isinstance(item, int):
+            return self.parts[item]
+
+        return ' '.join(self.parts[item])
+
     def __len__(self):
         """
         :return: the len() of self.parts
